/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *  Portions (c) the Coaster Development Team
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gtkmm/main.h>
#include <libgnome/gnome-init.h>
#include <libgnomeui/gnome-ui-init.h>

#include "gcs-mainwindow.h"
#include "gcs-i18n.h"

namespace gcs
{

    Glib::OptionGroup option_group("GNOME Colorscheme",
            "A Colorscheme Generator",
            "A tool for generating pleasing colorschemes from an initial color");

    bool colorscheme_debug = false;

    void setup_option_group(Glib::OptionContext& context,
            const Glib::ustring& text_domain)
    {
        Glib::OptionEntry entry1;
        entry1.set_long_name("debug");
        entry1.set_description("Enable Debugging output");
        option_group.add_entry(entry1, colorscheme_debug);

        option_group.set_translation_domain(text_domain);
        context.set_main_group(option_group);
    }

} // namespace gcs

int main(int argc, char **argv)
{
    bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
    textdomain(GETTEXT_PACKAGE);

    Glib::OptionContext context("A Colorscheme generation Tool");
    gcs::setup_option_group(context, GETTEXT_PACKAGE);
    // this Gtk::Main constructor requires gtkmm 2.6
    Gtk::Main ColorSchemeApp(argc, argv, context);
    gcs::MainWindow& w = gcs::MainWindow::Instance();

    Gtk::Main::run(w);

    return 0;
}

/** \mainpage GNOME Colorscheme Developer Documentation
 *
 * \section Introduction
 * This document provides an overview of the code of the GNOME Colorscheme
 * application.  Obviously this information will be most likely of interest to
 * those who want to hack on Gnome Colorscheme or contribute to its
 * development.  Obviously you can get all of this information simply from
 * looking at the code, but this presents the information in a much
 * easier-to-reference way.  Additions and corrections are welcome to this
 * documentation, as well as to the code itself.
 *
 * \section getting-started Getting Started
 * Everything in the application should be inside the 'gcs' namespace, which is
 * further divided into functional groups like widgets or dialog windows.  A
 * good place to start is to to get an idea of what the application is about is
 * the MainWindow class.  This is the main window of the application.  The
 * Color and Scheme classes are also interesting since they do a majority of
 * the work.  Initially the plan was to split core things like this out into
 * its own library, but I'm not sure how useful that would be.  It could still
 * be done in the future, but I don't really have any plans to do so at this
 * point.  
 */
